## Politika kolačića

Sukladno Uredbi br. 196/2003, koja je zamijenila Zakon br. 675/1996 o zaštiti osobnih podataka, obavještavamo Vas da ispunjavanjem ovog obrasca i slanjem ove poruke putem e-pošte pristajete na obradu vaših osobnih podataka (osjetljivi podaci neće biti obrađivani na bilo koji način) koje je GeoSolutions SAS stekao putem elektroničkih i/ili automatiziranih alata. U svakom slučaju možete ostvariti svoja prava koja su Vam dodijeljena sukladno Zakonodavnoj uredbi br. 196/2003 (pristup podacima, ažuriranja, integracija, otkazivanje). Klikom na gumb "Prihvati" potvrđujete da ste pročitali ovaj tekst i da pristajete na obradu vaših osobnih podataka. U bilo kojem trenutku možete zatražiti od osoblja GeoSolutions SAS web stranica da vas odjave sa usluge slijedeći upute na kraju svake poruke.

#### Kolačići i njihova korist za Vas

Naša web stranica koristi kolačiće, kao i gotovo sve web stranice, kako bi Vam pružila najbolje moguće iskustvo. Kolačići su male tekstualne datoteke koje se pohranjuju na vašem računalu ili mobilnom telefonu prilikom pregledavanja web stranica

Naši kolačići pomažu kako bi:

- Naše web stranice radile na način na koji Vi očekujete
- Zapamtili Vaše postavke za vrijeme i između različitih posjeta
- Poboljšali brzinu/sigurnost web stranice
- Omogućili dijeljenje stanica sa socijanlnim mrežama kao npr. Facebook

Ne koristimo kolačiće za:

- Prikupljanje bilo kojeg osobnog podatka (bez vašeg izričitog dopuštenja)
- Prikupljanje bilo kojeg osjetljivog podatka (bez vašeg izričitog dopuštenja)
- Proslijeđivanje podataka nekoj od oglašivačkih mreža
- Prenošenje osobnih podataka trećim stranama
- Plaćanje provizije

Možete saznati više o svim kolačićima koje koristimo ispod.

Ako su postavke vašeg softvera koji koristite za pregled ove web stranice (vaš preglednik) prilagođene za prihvaćanje kolačića, uzimamo to i vašu daljnju upotrebu naše web stranice kao da se podrazumijeva da ste suglasni sa ovakvim načinom rada. Ako želite ukloniti ili ne koristiti kolačiće s naše web stranice, možete saznati kako to učiniti u nastavku, ali to će vjerojatno značiti da naša web stranica neće raditi na način kako biste očekivali.

#### Naši kolačići

Koristimo kolačiće kako bi naša web stranica radila uključujući i:

- Pamćenje Vaših postavki pretraživanja
- Korisničke podatke za prijavu na WMS, WFS, WPS putem HTTP zahtjeva

Nema načina da se spriječi postavljanje ovih kolačića, osim da ne koristite našu web stranicu.

#### Kolačići trećih strana

Naša stranica, poput većine web stranica, uključuje i funkcionalnosti koju pružaju treće strane. Uobičajeni primjer je ugrađeni YouTube videozapis. Naša web stranica uključuje slijedeće koje koriste kolačiće:

- Google
- Cloudflare

#### Kolačići socijalnih mreža

Na taj način jednostavno možete "lajkati" ili dijeliti naš sadržaj na Facebook i Twitter koje smo uključili u dijeljenje gumba na našoj web stranici. Kolačiće postavljaju:

- Twitter
- Facebook
- Linkedin
- Google +

Postavke privatnosti u ovim slučajevima će se razlikovati od društvene mreže do društvene mreže i ovisiti će o postavkama privatnosti koje ste odabrali na tim mrežama.

#### Isključivanje kolačića

Kolačiće obično možete isključiti prilagodbom postavki preglednika kako biste spriječili prihvaćanje kolačića (saznajte kako ovdje). Međutim, to će vjerojatno ograničiti funkcionalnost našeg i velikog broja web stranica na svijetu jer su kolačići standardni dio suvremenijih web stranica.

Može biti da se Vaša zabrinutost oko kolačića odnosi na tzv. "Spyware". Umjesto isključivanja kolačića u vašem pregledniku, možete otkriti da anti-spyware softver postiže isti cilj automatski brišući kolačiće koji se smatraju invazivnim. Saznajte više o upravljanju kolačićima pomoću antispyware softvera.